<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form,
	\Nette\Utils\DateTime;

class ArticlePresenter extends SecuredPresenter
{

	/** @var \App\Model\ArticleModel @inject */
	public $articleModel;
	
	/** @var \App\Model\MenuModel @inject */
	public $menuModel;
	
	private $articleId = NULL;

	private $menuId;

	private $articleRow;

	private $menuData;
	

	public function actionDefault($id)
	{
		$this->menuData = $this->menuModel->findById($id);
	}

	public function renderDefault($id)
	{
		$this->template->menuRow = $this->menuModel->findById($id);

		$actualTime = new DateTime('midnight');

		$this->template->actualTime = $actualTime;

		//bez kontroly data
		//$this->template->articles = $this->articleModel->getArticles($this->menuData->id)->where(['archived ? OR date_end >= ?' => [FALSE, $actualTime]])->order('created DESC');
		//$this->template->archivedArticles = $this->articleModel->getArticles($this->menuData->id)->where(['archived ? OR date_end < ?' => [TRUE, $actualTime]])->order('created DESC');

		// nefunguje
		$this->template->articles = $this->articleModel->getArticles($this->menuData->id)->where(['archived' => FALSE, 'date_end >=' => $actualTime])->order('created DESC');
		$this->template->archivedArticles = $this->articleModel->getArticles($this->menuData->id)->where(['archived ? OR date_end < ?' => [TRUE, $actualTime]])->order('created DESC');
	}

	public function handleArchiveArticle($articleId)
	{
		$articleRow = $this->articleModel->archiveArticle($articleId);

		if ($articleRow->archived === 1) {
			$this->flashMessage('Článek je nyní archivovaný', 'alert-info');
		} else {
			$this->flashMessage('Článek již není archivovaný', 'alert-info');
		}

		$this->redirect('this');
	}

	public function handleRemoveArticle($articleId)
	{
		if ($this->user->isInRole('superadmin')) {
			$this->articleModel->delete($articleId);
			$this->flashMessage('Článek byl úspěšně smazán.', 'alert-success');
		}
		$this->redirect('this');
	}

	public function handleToggleVisibility($articleId)
	{
		$articleRow = $this->articleModel->toggleVisibility($articleId);

		if ($articleRow->visible === 1) {
			$this->flashMessage('Článek je nyní skrytý', 'alert-danger');
		} else {
			$this->flashMessage('Článek je nyní viditelný', 'alert-success');
		}
		
		$this->redirect('this');
	}

	public function actionNew($id)
	{
		$this->menuId = $id;
		$this->template->menuId = $id;
	}


	protected function createComponentNewArticleForm()
	{
		$form = $this->makeArticleForm();

		$form->onSuccess[] = callback($this, 'newArticleFormSucceded');
		return $form;
	}


	private function makeArticleForm()
	{
		$form = new Form;
		$form->addText('name', 'Název článku')
			->setRequired('Nevyplnili jste název článku');
		$form->addTextarea('extract', 'Úryvek článku (Zobrazí se ve výpisu článků)')
			->setRequired('Nevyplnili jste úryvek článku');
		$form->addTextarea('content', 'Obsah článku')
		    ->setRequired('Nevyplnili jste obsah článku');
		$form->addText('date_end', 'Zobrazit do');    
		$form->addSubmit('submit', 'Uložit');

		if (!is_null($this->articleId)) {
			$form->setDefaults($this->articleModel->findById($this->articleId)->toArray());
		}

		return $form;
	}


	public function newArticleFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {

			$values->date_end = DateTime::createFromFormat('d.m.Y', $values->date_end);
	
			$this->articleModel->add(
				array_merge(
					(array) $values, array(
				'created' => new \Nette\DateTime(),
				'date_end' => $values->date_end,
				'last_update' => new \Nette\DateTime(),
				'menu_id' => $this->menuId
					)
				)
			);
			$this->flashMessage('Článek byl úspěšně uložen.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Článek se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect(':Admin:Article:', $this->menuId);
	}


	public function actionEdit($id)
	{
		$this->articleRow = $this->articleModel->findById($id);
		$this->template->menuId = $this->articleRow->menu_id;
	}


	protected function createComponentEditArticleForm()
	{
		$form = $this->makeArticleForm();

		$form->setDefaults(array(
			'name' => $this->articleRow->name,
			'extract' => $this->articleRow->extract,
			'content' => $this->articleRow->content,
			'date_end' => $this->articleRow->date_end->format('d.m.Y')
		));

		$form->onSuccess[] = callback($this, 'editArticleFormSucceded');
		return $form;
	}


	public function editArticleFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$this->articleRow->update(array_merge(
					(array) $values, array('last_update' => new \Nette\DateTime())
				)
			);
			$this->flashMessage('Článek byl úspěšně uložen.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Článek se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('this');
	}

}
