<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form,
	\Nette\Utils\DateTime;

class CategoryPresenter extends SecuredPresenter
{

	/** @var \App\Model\CategoryModel @inject */
	public $categoryModel;

	/** @var \App\Model\DocumentModel @inject */
	public $documentModel;

	private $categoryData;

	private $documentRow;

	private $documentId;


	public function renderDefault()
	{
		$this->template->categories = $this->categoryModel->findAll();
	}


	public function actionDocuments($id)
	{
		$this->categoryData = $this->categoryModel->findById($id);
	}


	public function renderDocuments()
	{	
		$actualTime = new DateTime('midnight');

		$this->template->actualTime = $actualTime;
		$this->template->documents = $this->documentModel->findByCategoryId($this->categoryData->id)
		->where(['archived' => FALSE, 'date_end >=' => $actualTime])->order('created DESC');
		$this->template->archivedDocuments = $this->documentModel->findByCategoryId($this->categoryData->id)
		->where(['archived ? OR date_end < ?' => [TRUE, $actualTime]])->order('created DESC');
	}

	public function handleArchiveDocument($documentId)
	{
		$documentRow = $this->documentModel->archiveDocument($documentId);

		if ($documentRow->archived === 1) {
			$this->flashMessage('Dokument je nyní archivovaný', 'alert-info');
		} else {
			$this->flashMessage('Dokument již není archivovaný', 'alert-info');
		}

		$this->redirect('this');

	}

	public function handleToggleVisibility($documentId)
	{
		$documentRow = $this->documentModel->toggleVisibility($documentId);

		if ($documentRow->visible === 1) {
			$this->flashMessage('Dokument je nyní skrytý', 'alert-danger');
		} else {
			$this->flashMessage('Dokument je nyní viditelný', 'alert-success');
		}
		
		$this->redirect('this');
	}

	public function handleRemoveCategory($id)
	{
		if ($this->user->isInRole('superadmin')) {
			try {
				$documents = $this->documentModel->findByCategoryId($id);
				foreach ($documents as $document) {
					if (file_exists(WWW_DIR . '/documents/' . $document->category_id . '/' . $document->name) && !is_dir(WWW_DIR . '/documents/' . $document->category_id . '/' . $document->name))
						unlink(WWW_DIR . '/documents/' . $document->category_id . '/' . $document->name);
					if (file_exists(WWW_DIR . '/documents/' . $document->category_id . '/admin_thumb_' . $document->name) && !is_dir(WWW_DIR . '/documents/' . $document->category_id . '/admin_thumb_' . $document->name))
						unlink(WWW_DIR . '/documents/' . $document->category_id . '/admin_thumb_' . $document->name);
					$this->documentModel->delete($document->id);
				}
				if (is_dir(WWW_DIR . '/documents/' . $id))
					rmdir(WWW_DIR . '/documents/' . $id);
				$this->categoryModel->delete($id);
				$this->flashMessage('Kategorie byla úspěšně smazána.', 'alert-success');
			} catch (\PDOException $e) {
				$this->flashMessage('Kategorii se nepodařilo smazat.', 'alert-danger');
			}
		}
		$this->redirect('this');
	}

	public function handleToggleCategoryVisibility($categoryId)
	{
		$categoryRow = $this->categoryModel->toggleCategoryVisibility($categoryId);

		if ($categoryRow->visible === 1) {
			$this->flashMessage('Kategorii je nyní skrytá', 'alert-danger');
		} else {
			$this->flashMessage('Kategorie je nyní viditelná', 'alert-success');
		}
		
		$this->redirect('this');
	}


	public function handleRemoveDocument($id)
	{
		if ($this->user->isInRole('superadmin')) {
			$document = $this->documentModel->findById($id);
			@unlink(WWW_DIR . '/documents/' . $document->category_id . '/' . $document->name);
			@unlink(WWW_DIR . '/documents/' . $document->category_id . '/admin_thumb_' . $document->name);
			$this->documentModel->delete($id);
		}
		$this->redirect(':Admin:Category:documents', $document->category_id);
	}


	protected function createComponentCategoryNameForm()
	{
		$form = new Form;
		$form->addText('name', 'Název kategorie')
			->setRequired('Není zadaný žádný název kategorie');
		$form->addHidden('category_id', $this->categoryData->id);
		$form->addSubmit('submit', 'Uložit změny');
		$form->setDefaults(array(
			'name' => $this->categoryData->name
		));
		
		$form->onSuccess[] = callback($this, 'categoryNameFormSucceded');

		return $form;
	}


	public function categoryNameFormSucceded(Form $form)
	{
		$values = $form->getValues();
		
		$this->categoryModel->update($values->category_id, array('name' => $values->name));
		$this->flashMessage('Jméno kategorie bylo úspěšně uloženo.', 'alert-success');
		
		$this->redirect('this');
	}


	protected function createComponentDocumentsForm()
	{
		$form = new Form;
		$form->addUpload('document', 'Dokument')
			->setRequired('Nevložili jste žádný soubor')
			->addCondition(Form::FILLED)
			->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost souboru je 5 MB.', 5000 * 1024 /* v bytech */);
		$form->addText('date_from', 'Zobrazit od');
		$form->addText('date_end', 'Zobrazit do');
		$form->addHidden('category_id', $this->categoryData->id);
		$form->addSubmit('submit', 'Nahrát dokument')
			->setAttribute('class', 'btn btn-default');

		$form->onSuccess[] = callback($this, 'documentsFormSucceded');

		return $form;
	}


	public function documentsFormSucceded(Form $form)
	{
		$values = $form->getValues();
		
		$file = $form['document']->getValue();

		if ($file->isOK()) {
			$dir = '/documents/' . $values->category_id;
			if (!is_dir(WWW_DIR . $dir)) {
				mkdir(WWW_DIR . $dir);
			}

			$values->date_from = DateTime::createFromFormat('d.m.Y', $values->date_from);
			$values->date_end = DateTime::createFromFormat('d.m.Y', $values->date_end);
			$values->date_from->modify('midnight');
			$values->date_end->modify('midnight');

			if ($values->date_from > $values->date_end) {
				$form['date_from']->addError('Datum od musí být menší/stejné než datum do');
				return;
			}

			$documentRow = $this->documentModel->add(array(
				'category_id' => $values->category_id,
				'date_from' => $values->date_from,
				'date_end' => $values->date_end,
				'created' => new DateTime()
			));
			$filename = $documentRow->id . '_' . $file->getSanitizedName();
			
			$documentRow->update(array(
				'name' => $filename,
				'path' => $dir . '/' . $filename
			));
			$file->move(WWW_DIR . $dir . '/' . $filename);
		}
		$this->redirect('this');
	}


	protected function createComponentNewCategoryForm()
	{
		$form = $this->makeCategoryForm();
		$form->onSuccess[] = callback($this, 'newCategoryFormSucceded');
		return $form;
	}


	public function newCategoryFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$this->categoryModel->add(array(
				'name' => $values->name,
				'created' => DateTime(),
				'last_update' => DateTime()
			));
			$this->flashMessage('Kategorie byla úspěšně přidána.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Kategorii se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect(':Admin:Category:');
	}


	private function makeCategoryForm($id = NULL)
	{
		$form = new Form;
		$form->addText('name', 'Název')
			->setRequired('Nevyplnili jste název kategorie');

		$form->addSubmit('submit', 'Uložit');
		
		return $form;
	}

	public function actionEdit($id)
	{
		
		$this->documentRow = $this->documentModel->findById($id);
	}

	public function renderEdit()
	{
		$this->template->documentRow = $this->documentRow;
	}

	private function makeDocumentForm()
	{
		$form = new Form;
		$form->addText('name', 'Název souboru')
			->setRequired('Nevyplnili jste název článku');
		$form->addText('date_from', 'Zobrazit od');
		$form->addText('date_end', 'Zobrazit do');
		$form->addSubmit('submit', 'Uložit');

		if (!is_null($this->documentId)) {
			$form->setDefaults($this->documentModel->findById($this->documentId)->toArray());
		}

		return $form;
	}

	protected function createComponentEditDocumentForm()
	{
		$form = $this->makeDocumentForm();

		$form->setDefaults(array(
			'name' => $this->documentRow->name,
			'date_from' => $this->documentRow->date_from->format('d.m.Y'),
			'date_end' => $this->documentRow->date_end->format('d.m.Y')
		));

		$form->onSuccess[] = callback($this, 'editDocumentFormSucceded');
		return $form;
	}


	public function editDocumentFormSucceded(Form $form)
	{
		$values = $form->getValues();
        
		$values->date_from = DateTime::createFromFormat('d.m.Y', $values->date_from);
			$values->date_end = DateTime::createFromFormat('d.m.Y', $values->date_end);
			$values->date_from->modify('midnight');
			$values->date_end->modify('midnight');

		if ($values->date_from > $values->date_end) {
				$form['date_from']->addError('Datum od musí být menší/stejné než datum do');
				return;
			}

		try {
			$this->documentRow->update($values);
			$this->flashMessage('Dokument byl úspěšně změněn.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Dokument se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('this');
	}

}
