<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form;

class CouncilorPresenter extends SecuredPresenter
{

	/** @var \App\Model\CouncilorModel @inject */
	public $councilorModel;
	
	private $councilorId = NULL;

	private $councilors;

	private $councilorRow;


	public function renderDefault()
	{
		$this->template->councilors = $this->councilorModel->findAll();
	}


	public function actionNew($id)
	{

		$this->template->councilorId = $id;
	}


	protected function createComponentNewCouncilorForm()
	{
		$form = $this->makeCouncilorForm();

		$form->onSuccess[] = callback($this, 'newCouncilorFormSucceded');
		return $form;
	}


	private function makeCouncilorForm()
	{
		$form = new Form;
		$form->addText('title_before', 'Titul před');
		$form->addText('title_after', 'Titul za');
		$form->addText('first_name', 'Jméno')
			->setRequired('Nevyplnili jste křestní jméno');
		$form->addText('last_name', 'Příjmení')
			->setRequired('Nevyplnili jste příjmení');
		$form->addText('function', 'Funkce')
			->setRequired('Nevyplnili jste funkci');
		$form->addText('phone', 'Telefon');
		$form->addText('email', 'E-mail')
			-> addRule(Form::EMAIL, 'Email je ve špatném formátu', 'karluvemail@seznam.cz');
		
		$form->addSubmit('submit', 'Uložit');

		if (!is_null($this->councilorId)) {

			$form->setDefaults($this->councilorModel->findById($this->councilorId)->toArray());
		}

		return $form;
	}


	public function newCouncilorFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$councilorRow = $this->councilorModel->add((array) $values);
			
			$this->flashMessage('Zastupitele se podařilo úspěšně uložit.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Zastupitele se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('edit', $councilorRow->id);
	}


	public function actionEdit($id)
	{
		
		$this->councilorRow = $this->councilorModel->findById($id);
	}


	protected function createComponentEditCouncilorForm()
	{
		$form = $this->makeCouncilorForm();
		$form->setDefaults($this->councilorRow->toArray());

		$form->onSuccess[] = callback($this, 'editCouncilorFormSucceded');
		return $form;
	}


	public function editCouncilorFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$this->councilorRow->update($values);
			$this->flashMessage('Zastupitel byl úspěšně uložen.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Zastupitele se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('this');
	}


	public function handleRemoveCouncilor($councilorId)
	{
		$this->councilorModel->delete($councilorId);
		$this->flashMessage('Uživatel byl úspěšně smazán.', 'alert-success');
		$this->redirect('this');
	}

}
