<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form,
    \Nette\Utils\Strings;


/**
 * Menu presenter.
 */
class MenuPresenter extends SecuredPresenter
{

	/** @var \App\Model\MenuModel @inject */
	public $menuModel;

	/** @var \App\Model\InfoModel @inject */
	public $infoModel;

	private $menuRow;


	public function renderDefault()
	{
		$this->template->menu = $this->menuModel->findBy(['lvl' => 1])->order('order ASC');
	}


	public function handleRemoveMenu($menuId)
	{
		if ($this->user->isInRole('superadmin')) {
			try {
				$this->menuModel->delete($menuId);
				$this->flashMessage('Položka menu byla úspěšně smazána.', 'alert-success');
			} catch (\PDOException $e) {
				$this->flashMessage('Není možné smazat položku menu, protože obsahuje další položky menu. 
					Před jejím smazáním položky přesuňte do jiného menu nebo je smažte.', 'alert-danger');
			}
		}
		$this->redirect('this');
	}


	public function handleMoveItemUp($menuId)
	{

		$this->menuModel->moveItemUp($menuId);

		$this->redirect('this');
	}


	public function handleMoveItemDown($menuId)
	{

		$this->menuModel->moveItemDown($menuId);

		$this->redirect('this');
	}

	public function handleSetHomepage($menuId)
	{
		$this->menuModel->setHomepage($menuId);

		$this->redirect('this');

	}

	public function handleToggleVisibility($menuId)
	{
		$menuRow = $this->menuModel->toggleVisibility($menuId);

		if ($menuRow->visible === 0) {
			$this->flashMessage('Položka menu je nyní skrytá', 'alert-danger');
		} else {
			$this->flashMessage('Položka menu je nyní viditelná', 'alert-success');
		}
		
		$this->redirect('this');
	}


	public function actionEdit($id)
	{
		$this->menuRow = $this->menuModel->findById($id);
	}


	protected function createComponentEditMenuForm()
	{

		$form = $this->makeMenuForm();

		$form->setDefaults($this->menuRow->toArray());

		$form->onSuccess[] = function(Form $form) {
			$values = $form->getValues();

			$values->url_name = Strings::webalize($values->name);

			if($this->menuModel->findBy(['url_name' => $values->url_name, 'menu_id' => $values->menu_id, 'NOT id' => $this->menuRow->id])->count() > 0)
			{
				$form['name']->addError('Název položky menu je již v databázi, zvolte si jiný');
				return;
			}

			try {
				$this->menuModel->updateItem($this->menuRow, $values);
				$this->flashMessage('Položka menu byla úspěšně uložena.', 'alert-success');
			} catch (\PDOException $e) {
				$this->flashMessage('Položku menu se nepodařilo uložit.', 'alert-danger');
			}
			$this->redirect(':Admin:Menu:');
		};

		return $form;
	}


	protected function createComponentNewMenuForm()
	{
		$form = $this->makeMenuForm();
		$form->onSuccess[] = function(Form $form) {
			$values = $form->getValues();

			$values->url_name = Strings::webalize($values->name);

			if($this->menuModel->findBy(['url_name' => $values->url_name, 'menu_id' => $values->menu_id])->count() > 0)
			{
				$form['name']->addError('Název položky menu je již v databázi, zvolte si jiný');
				return;
			}

			try {
				$this->menuModel->addItem($values);
				$this->flashMessage('Položka menu byla úspěšně přidána.', 'alert-success');
			} catch (\PDOException $e) {
				$this->flashMessage('Položku menu se nepodařilo uložit.', 'alert-danger');
			}
			$this->redirect(':Admin:Menu:');
		};

		return $form;
	}


	private function makeMenuForm()
	{

		$types = array('articles' => 'Výpis článků', 'text' => 'Textová stránka');

		if ((isset($this->menuRow) && $this->menuRow->type === 'info') || $this->menuModel->findBy(['type' => 'info'])->count() === 0) {
			$types['info'] = 'Informace o obci';
		}
		if ((isset($this->menuRow) && $this->menuRow->type === 'services') || $this->menuModel->findBy(['type' => 'services'])->count() === 0) {
			$types['services'] = 'Služby';
		}
		if ((isset($this->menuRow) && $this->menuRow->type === 'councilors') || $this->menuModel->findBy(['type' => 'councilors'])->count() === 0) {
			$types['councilors'] = 'Zastupitelstvo';
		}
		if ((isset($this->menuRow) && $this->menuRow->type === 'gallery') || $this->menuModel->findBy(['type' => 'gallery'])->count() === 0) {
			$types['gallery'] = 'Galerie';
		}
		if ((isset($this->menuRow) && $this->menuRow->type === 'board') || $this->menuModel->findBy(['type' => 'board'])->count() === 0) {
			$types['board'] = 'Úřední deska';
		}
		if ((isset($this->menuRow) && $this->menuRow->type === 'registry') || $this->menuModel->findBy(['type' => 'registry'])->count() === 0) {
			$types['registry'] = 'E-Podatelna';
		}
		

		$menuSelection = $this->menuModel->findBy(['lvl' => 1])->order('order ASC');
		$menuArray = array();

		if (sizeOf($menuSelection) > 0) {
			foreach ($menuSelection as $menuRow) {
				$menuArray[$menuRow->id] = $menuRow->name;
				$childs = $menuRow->related('menu')->order('order ASC');
				
				foreach ($childs as $menuRow) {
					$menuArray[$menuRow->id] = '└ '.$menuRow->name;
					$grandChilds = $menuRow->related('menu')->order('order ASC');

					foreach ($grandChilds as $menuRow) {
						$menuArray[$menuRow->id] = '└─ '.$menuRow->name;
					}
				}
			}
		}

		$form = new Form;
		$form->addText('name', 'Název')
			->setRequired('Nevyplnili jste název');
		$form->addSelect('type', 'Typ', $types)
			->setPrompt('Vyberte');
		$form->addSelect('menu_id', 'Nadřazená položka', $menuArray)
			->setPrompt('Vyberte');

		$form->addSubmit('submit', 'Uložit');

		return $form;
	}


	public function actionEditPage($id)
	{

		$this->menuRow = $this->menuModel->findById($id);
	}


	public function renderEditPage()
	{

		$this->template->menuRow = $this->menuRow;
	}


	protected function createComponentEditInfoForm()
	{
		$form = new Form;
		$form->addText('name', 'Jméno obce')
			->setRequired('Nevyplnili jste jméno obce');
		$form->addText('web', 'Webová stránka')
			->setRequired('Nevyplnili jste webovou stránku');
		$form->addText('ic', 'IČ')
			->setRequired('Nevyplnili jste IČ');
		$form->addText('dic', 'DIČ')
			->setRequired('Nevyplnili jste DIČ');
		$form->addText('street', 'Ulice a číslo popisné')
			->setRequired('Nevyplnili jste název ulice a číslo popisné');
		$form->addText('city', 'Město')
			->setRequired('Nevyplnili jste název města');
		$form->addText('psc', 'PSČ')
			->setRequired('Nevyplnili jste poštovní směrovací číslo');
		$form->addText('phone', 'Telefonní číslo')
			->setRequired('Nevyplnili jste webovou stránku');
		$form->addText('fax', 'FAX');
		$form->addText('email', 'E-mail')
			->addRule(Form::EMAIL, 'Email je ve špatném formátu', 'karluvemail@seznam.cz')
			->setRequired('Nevyplnili jste e-mail');
		$form->addText('bank', 'Číslo bankovního účtu')
			->setRequired('Nevyplnili jste číslo bankovního účtu');
		$form->addText('region', 'Kraj')
			->setRequired('Nevyplnili jste název kraje');
		$form->addText('district', 'Okres')
			->setRequired('Nevyplnili jste název okresu');
		$form->addText('population', 'Počet obyvatel')
			->setRequired('Nevyplnili jste počet obyvatel');
		$form->addText('area', 'Rozloha')
			->setRequired('Nevyplnili jste rozlohu');
		$form->addText('mon', 'Pondělí');
		$form->addText('tue', 'Úterý');
		$form->addText('wed', 'Středa');
		$form->addText('thu', 'Čtvrtek');
		$form->addText('fri', 'Pátek');
		$form->addText('sat', 'Sobota');
		$form->addText('sun', 'Neděle');
		$form->addText('facebook', 'Facebook');
		$form->addText('google_plus', 'Google plus');
		$form->addText('twitter', 'Twitter');
		$form->addText('youtube', 'YouTube');
		
		$form->addSubmit('submit', 'Uložit');

		$form->setDefaults($this->infoModel->findById(1)->toArray());

		$form->onSuccess[] = function(Form $form) {
			$values = $form->getValues();

			try {
				$this->infoModel->updateInfo($values);
				$this->flashMessage('Informace o obci byly úspěšně přidány.', 'alert-success');
			} catch (\PDOException $e) {
				$this->flashMessage('Informace o obci se nepodařilo uložit.', 'alert-danger');
			}
			$this->redirect('this');
		};

		return $form;
	}


	protected function createComponentEditTextForm()
	{
		$form = new Form;
		$form->addTextarea('content', 'Text');
		$form->addSubmit('submit', 'Uložit');

		$form->setDefaults($this->menuRow->toArray());

		$form->onSuccess[] = callback($this, 'editTextFormSucceded');
		return $form;
	}


	public function editTextFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$this->menuRow->update(array_merge(
					(array) $values, array('last_update' => new \Nette\DateTime())
				)
			);
			$this->flashMessage('Text byl úspěšně uložen.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Text se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('this');
	}

}
