<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form,
	\Nette\Application\Responses\FileResponse;

class RegistryPresenter extends SecuredPresenter
{

	/** @var \App\Model\RegistryModel @inject */
	public $registryModel;

	/** @var \App\Model\UserModel @inject */
	public $userModel;

	private $registryRow;

	public function renderDefault()
	{
		$this->template->registry = $this->registryModel->findBy(['approved' => '0'])->order('created DESC');
		$this->template->approvedRegistry = $this->registryModel->findBy(['approved' => '1'])->order('created DESC');
	}


	public function actionInfo($id)
	{
		$this->registryRow = $this->registryModel->findById($id);
	}

	public function renderInfo()
	{
		$this->template->registryRow = $this->registryRow;
	}


	public function handleRemoveRegistry($registryId)
	{
		if ($this->user->isInRole('superadmin')) {
			$this->registryModel->findById($registryId)->update(['vy']);
			$this->flashMessage('Žádost byl úspěšně smazána.', 'alert-success');
		}
		
		$this->redirect('default');
	}

	public function handleApproveRegistry($registryId)
	{
		$registryRow = $this->registryModel->approveRegistry($registryId);

		if ($registryRow->approved === 1) {
			$this->flashMessage('Žádost je nyní vyřízená', 'alert-info');
		} else {
			$this->flashMessage('Žádost je opět nevyřízená', 'alert-info');
		}

		$this->redirect('this');

	}

	public function handleShowFile($registryId)
	{
		$registryRow = $this->registryModel->findById($registryId);

		$extension = \Nette\Utils\Strings::lower(pathinfo($registryRow->path, PATHINFO_EXTENSION));

		//zobrazime soubor
		$path = WWW_DIR . '/../' . $registryRow->path;
		
		switch ($extension) {
			case 'pdf': header("Content-type: application/pdf");
				break;
			case 'jpg': header("Content-type: image/jpg");
				break;
			case 'png': header("Content-type: image/png");
				break;
			case 'jpeg': header("Content-type: image/jpg");
				break;
			case 'gif': header("Content-type: image/gif");
				break;
			case 'tiff': header("Content-type: image/tiff");
				break;

			default:
				$file = new FileResponse($path, $registryRow->filename);
				$this->sendResponse($file);
		}

		if (in_array($extension, array('pdf', 'jpg', 'jpeg', 'png', 'gif', 'tiff'))) {
			header("Content-Disposition: inline; filename={$path}");
			@readfile($path);
			$this->terminate();
		}
	}


}
