<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form;

class ServicePresenter extends SecuredPresenter
{

	/** @var \App\Model\ServiceModel @inject */
	public $serviceModel;

	private $serviceId = NULL;

	private $services;

	private $serviceRow;


	public function actionNew($id)
	{

		$this->template->serviceId = $id;
	}


	public function renderDefault()
	{

		$this->template->services = $this->serviceModel->findAll();
	}


	protected function createComponentNewServiceForm()
	{
		$form = $this->makeServiceForm();

		$form->onSuccess[] = callback($this, 'newServiceFormSucceded');
		return $form;
	}


	private function makeServiceForm()
	{
		$form = new Form;
		$form->addText('name', 'Název')
			->setRequired('Nevyplnili jste název');
		$form->addSelect('type', 'Typ', ['shop' => 'Prodejna', 'service' => 'Služba', 'institut' => 'Instituce', 'sport' => 'Sportovní klub',
				'organization' => 'Organizace', 'firm' => 'Firma', 'group' => 'Spolek', 'hotel' = 'Hotel', 'pension' => 'Penzion' ])
			->setPrompt('Vyberte');
		$form->addText('address', 'Adresa')
			->setRequired('Nevyplnili jste adresu');
		$form->addText('phone', 'Telefon')
			->setRequired('Nevyplnili jste telefon');
		$form->addText('email', 'Email')
			->addRule(Form::EMAIL, 'Email je ve špatném formátu', 'jmeno@email.com')
			->setRequired('Nevyplnili jste e-mail');
		$form->addText('ref_person', 'Odpovědná osoba');
		$form->addTextarea('content', 'O službě');

		$form->addSubmit('submit', 'Uložit');


		if (!is_null($this->serviceId)) {

			$form->setDefaults($this->serviceModel->findById($this->serviceId)->toArray());
		}

		return $form;
	}


	public function newServiceFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$serviceRow = $this->serviceModel->add(
				array_merge(
					(array) $values, array(
				'created' => new \Nette\DateTime(),
				'last_update' => new \Nette\DateTime(),
					)
				)
			);
			$this->flashMessage('Službu se podařilo úspěšně uložit.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Službu se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('edit', $serviceRow->id);
	}


	public function actionEdit($id)
	{
		
		$this->serviceRow = $this->serviceModel->findById($id);
	}


	protected function createComponentEditServiceForm()
	{
		$form = $this->makeServiceForm();
		$form->setDefaults($this->serviceRow->toArray());

		$form->onSuccess[] = callback($this, 'editServiceFormSucceded');
		return $form;
	}


	public function editServiceFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$this->serviceRow->update(array_merge(
					(array) $values, array('last_update' => new \Nette\DateTime())
				)
			);
			$this->flashMessage('Služba byla úspěšně uložena.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Službu se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('this');
	}


	public function handleRemoveService($serviceId)
	{
		$this->serviceModel->delete($serviceId);
		$this->flashMessage('Služba byla úspěšně smazána.', 'alert-success');
		$this->redirect('this');
	}

}
