<?php

namespace App\AdminModule\Presenters;

use \Nette\Application\UI\Form,
	\Nette\Utils\DateTime;

class UserPresenter extends SecuredPresenter
{

	/** @var \App\Model\UserModel @inject */
	public $userModel;

	private $userId = NULL;

	private $users;

	private $userRow;


	public function renderDefault()
	{
		$this->template->users = $this->userModel->findAll();
	}


	public function actionNew($id)
	{

		$this->template->userId = $id;
	}


	protected function createComponentNewUserForm()
	{
		$form = $this->makeUserForm();

		$form->onSuccess[] = callback($this, 'newUserFormSucceded');
		return $form;
	}


	private function makeUserForm()
	{
		$form = new Form;
		$form->addText('first_name', 'Křestní jméno')
			->setRequired('Nevyplnili jste křestní jméno');
		$form->addText('last_name', 'Příjmení')
			->setRequired('Nevyplnili jste příjmení');
		$form->addText('username', 'Uživatelské jméno')
			->setRequired('Nevyplnili jste uživatelské jméno');
		$form->addSelect('role', 'Role', ['admin' => 'Administrátor', 'superadmin' => 'Super administrátor'])
			->setPrompt('Vyberte');
		$form->addPassword('password', 'Heslo');
		
		if (!isset($this->userRow)) {
			$form['password']->setRequired('Nevyplnili jste heslo');
		}

		$form->addSubmit('submit', 'Uložit');


		if (!is_null($this->userId)) {
			$form->setDefaults($this->userModel->findById($this->userId)->toArray());
		}

		return $form;
	}


	public function newUserFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$values->created = new DateTime;
			$values->invalidate = new DateTime;
			$values->password = \Nette\Security\Passwords::hash($values->password);
			$userRow = $this->userModel->add($values);
			$this->flashMessage('Uživatele se podařilo úspěšně uložit.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Uživatele se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('edit', $userRow->id);
	}


	public function actionEdit($id)
	{

		$this->userRow = $this->userModel->findById($id);
	}


	protected function createComponentEditUserForm()
	{
		$form = $this->makeUserForm();
		$form->setDefaults($this->userRow->toArray());

		$form->onSuccess[] = callback($this, 'editUserFormSucceded');
		return $form;
	}


	public function editUserFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {
			$values->invalidate = new DateTime;
			if (!empty($values->password)) {
				$values->password = \Nette\Security\Passwords::hash($values->password);
			} else {
				unset($values->password);
			}
			$this->userRow->update($values);
			$this->flashMessage('Uživatel byl úspěšně uložen.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Uživatele se nepodařilo uložit.', 'alert-danger');
		}
		$this->redirect('this');
	}


	public function handleRemoveUser($userId)
	{
		if ($this->user->isInRole('superadmin')) {
			if($this->userModel->findAll()->count() > 1) {
				$this->userModel->delete($userId);
				$this->flashMessage('Uživatel byl úspěšně smazán.', 'alert-success');
			} else {
				$this->flashMessage('Uživatele se nepodařilo smazat.', 'alert-danger');
			}
		}
		$this->redirect('this');

	}

}
