<?php

namespace App\FrontModule\Presenters;

use \Nette\Application\UI\Form;

/**
 * Homepage presenter.
 */
class HomepagePresenter extends FrontBasePresenter
{
	/** @var \App\Model\MenuModel @inject */
	public $menuModel;

	/** @var \App\Model\InfoModel @inject */
	public $infoModel;

	/** @var \App\Model\ServiceModel @inject */
	public $serviceModel;

	/** @var \App\Model\CouncilorModel @inject */
	public $councilorModel;

	/** @var \App\Model\GalleryModel @inject */
	public $galleryModel;

	/** @var \App\Model\PhotoModel @inject */
	public $photoModel;

	/** @var \App\Model\RegistryModel @inject */
	public $registryModel;

	private $menuRow;

	public function actionDefault($category = NULL, $subcategory = NULL, $subsubcategory = NULL)
	{
		if($category !== NULL) {
			$menuRow = $this->menuModel->findBy(['lvl' => 1, 'url_name' => $category])->fetch();
			if (!$menuRow) {
				$this->error();
			} elseif ($subcategory !== NULL) {
				$menuRow = $this->menuModel->findBy(['menu_id' => $menuRow->id, 'url_name' => $subcategory])->fetch();
				if (!$menuRow) {
					$this->error();
				} elseif ($subsubcategory !== NULL) {
					$menuRow = $this->menuModel->findBy(['menu_id' => $menuRow->id, 'url_name' => $subsubcategory])->fetch();
					if (!$menuRow) {
						$this->error();
					}
				}
			}
			$this->menuRow = $menuRow;
		
		} else {
			$this->menuRow = $this->menuModel->findBy(['Hp' => 1])->fetch();
		}
	}

	public function renderDefault($category = NULL, $subcategory = NULL, $subsubcategory = NULL)
	{
		$this->template->menuRow = $this->menuRow;
		$this->template->serviceModel = $this->serviceModel;
		$this->template->category = $category;
		$this->template->councilorModel = $this->councilorModel;
		$this->template->infoModel = $this->infoModel;
		$this->template->galleryModel = $this->galleryModel;
		$this->template->photoModel = $this->photoModel;
	}

	public function actionNew($id)
	{

		$this->template->registryId = $id;
	}


	protected function createComponentNewRegistryForm()
	{
		$form = $this->makeRegistryForm();

		$form->onSuccess[] = callback($this, 'newRegistryFormSucceded');
		return $form;
	}


	private function makeRegistryForm()
	{
		$form = new Form;
		$form->addText('name', 'Jméno a příjmení')
			->setRequired('Nevyplnili jste jméno a příjmení');
		$form->addText('email', 'E-mail')
			->setRequired('Nevyplnili jste e-mail')
			-> addRule(Form::EMAIL, 'Email je ve špatném formátu', 'karluvemail@seznam.cz');
		$form->addText('street', 'Ulice a č.p.')
			->setRequired('Nevyplnili jste ulici a č.p.');
		$form->addText('city', 'Město')
			->setRequired('Nevyplnili jste město');
		$form->addTextarea('text', 'Žádost');
		$form->addUpload('document', 'Dokument')
			->addCondition(Form::FILLED)
			->addRule(Form::MAX_FILE_SIZE, 'Maximální velikost dokumentu je 1 MB.', 1000 * 1024 /* v bytech */);
			
		$form->addSubmit('submit', 'Uložit');

		return $form;
	}


	public function newRegistryFormSucceded(Form $form)
	{
		$values = $form->getValues();

		try {

			$registryRow = $this->registryModel->add(
				array(
					'name' => $values->name,
					'email' => $values->email,
					'street' => $values->street,
					'city' => $values->city,
					'text' => $values->text,
					'created' => new \Nette\Utils\DateTime()
				)
			);

			$file = $form['document']->getValue();

			if ($file->isOK()) {
				$dir = 'files/registry';
				if (!is_dir(WWW_DIR. '/../' . $dir)) {
					mkdir(WWW_DIR. '/../' . $dir);
				}

				$filename = $registryRow->id . '_' . $file->getSanitizedName();
				
				$registryRow->update(array(
					'filename' => $filename,
					'path' => $dir . '/' . $filename
				));
				$file->move(WWW_DIR. '/../' . $dir . '/' . $filename);
			}

			$this->flashMessage('Žádost se podařilo úspěšně odeslat.', 'alert-success');
		} catch (\PDOException $e) {
			$this->flashMessage('Žádost se nepodařilo úspěšně odeslat.', 'alert-danger');
		}
		$this->redirect('this');
	}

}
