<?php

namespace App\Model;

use \Nette\Object;

/**
 * Provádí operace nad databázovou tabulkou.
 */
abstract class BaseModel extends Object
{
    /** @var Nette\Database\Context */
    protected $connection;
	
	private $tableName;

    public function __construct(\Nette\Database\Context $db)
    {
        $this->connection = $db;
		$this->getTableName();
    }
    
	public function getTableName()
	{
		if (is_null($this->tableName)) {
			$m = array();
			preg_match('#(\w+)Model$#', get_class($this), $m);
			$this->tableName = strtolower(preg_replace('/\B([A-Z])/', '_$1', $m[1]));
		}
		return $this->tableName;
	}
	
    public function getTable()
	{
        return $this->connection->table($this->getTableName());
	}
	
	public function getConnection()
	{
		return $this->connection;
	}
	
	public function get($id)
	{
		return $this->getTable()->get($id);
	}
	
	public function findAll()
	{
		return $this->getTable();
	}

	/**
     * Vrací řádky podle filtru, např. array('name' => 'John').
     * @return Nette\Database\Table\Selection
     */
    public function findBy(array $by)
    {
        return $this->getTable()->where($by);
    }
	
	/**
	 * Vrátí konkrétní řádek z databáze
	 * @param mixed $id
	 * @return Nette\Database\Table\ActiveRow
	 */
	public function findById($id)
	{
		return $this->getTable()->get($id);
	}

	public function add($values)
	{
		return $this->getTable()->insert($values);
	}

	public function delete($id)
	{
		$this->findById($id)->delete();
	}
	
	public function update($id, $values)
	{
		return $this->findById($id)->update($values);
	}

}